==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/ja.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "設定を更新しました。",
"Activity" => "アクティビティ",
"A file or folder has been <strong>shared</strong>" => "ファイルまたはフォルダーが<strong>共有</strong>されました",
"A new file or folder has been <strong>created</strong> in a shared folder" => "共有フォルダ内でファイルまたはフォルダーが<strong>作成</strong>されました",
"A file or folder has been <strong>changed</strong> in a shared folder" => "共有フォルダ内でファイルまたはフォルダーが<strong>変更</strong>されました",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "共有フォルダからファイルまたはフォルダーが<strong>削除</strong>されました",
"You created %1\$s" => "あなたは %1\$s を作成しました",
"%2\$s created %1\$s" => "%2\$s は%1\$s を作成しました",
"You changed %1\$s" => "あなたは %1\$s を変更しました",
"%2\$s changed %1\$s" => "%2\$s は%1\$s を変更しました",
"You deleted %1\$s" => "あなたは %1\$s を削除しました",
"%2\$s deleted %1\$s" => "%2\$s は %1\$s を削除しました",
"You shared %1\$s with %2\$s" => "あなたは %1\$s を %2\$s と共有しました",
"You shared %1\$s with group %2\$s" => "あなたは %1\$s をグループ %2\$s と共有しました",
"%2\$s shared %1\$s with you" => "%2\$s は %1\$s をあなたと共有しました",
"Activity notification" => "アクティビティ通知",
"All Activities" => "すべてのアクティビティ",
"Activities by you" => "あなたのアクティビティ",
"Activities by others" => "他人のアクティビティ",
"Shares" => "共有",
"Files" => "ファイル",
"%s and %s" => "%s と %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s と <strong class=\"tooltip\" title=\"%s\">それ以外に %n 個</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s と それ以外に %n 個"),
"Hello %s," => "%s さんこんにちは、",
"You are receiving this email because in the last hour the following things happened at %s" => "このメールは、最近１時間に %s で以下の事象が発生したことをお知らせするものです。",
"You are receiving this email because in the last day the following things happened at %s" => "このメールは、最近１日間に %s で以下の事象が発生したことをお知らせするものです。",
"You are receiving this email because in the last week the following things happened at %s" => "このメールは、最近１週間に %s で以下の事象が発生したことをお知らせするものです。",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "%s の使用を開始すると、ここでイベントリストを見ることができます。",
"No more events to load" => "これ以上読み込むイベントはありません",
"Enable RSS feed" => "RSSフィードを有効にする",
"Notifications" => "通知",
"Mail" => "メール",
"Stream" => "ストリーム",
"You need to set up your email address before you can receive notification emails." => "通知メールを受け取る前にメールアドレスを設定する必要があります。",
"Send emails:" => "メールを送信:",
"Hourly" => "1時間毎",
"Daily" => "毎日",
"Weekly" => "毎週",
"Activity feed" => "アクティビティフィード",
"Personal activity feed for %s" => "\"%s\" の個人アクティビティフィード"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/ja.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "設定を更新しました。",
"Activity" => "アクティビティ",
"A file or folder has been <strong>shared</strong>" => "ファイルまたはフォルダーが<strong>共有</strong>されました",
"A new file or folder has been <strong>created</strong>" => "新しいファイルもしくはフォルダが <strong>作成</strong> されました",
"A file or folder has been <strong>changed</strong>" => "ファイルもしくはフォルダが <strong>変更</strong> されました",
"A file or folder has been <strong>deleted</strong>" => "ファイルもしくはフォルダが <strong>削除</strong> されました",
"You created %1\$s" => "あなたは %1\$s を作成しました",
"%2\$s created %1\$s" => "%2\$s は%1\$s を作成しました",
"You changed %1\$s" => "あなたは %1\$s を変更しました",
"%2\$s changed %1\$s" => "%2\$s は%1\$s を変更しました",
"You deleted %1\$s" => "あなたは %1\$s を削除しました",
"%2\$s deleted %1\$s" => "%2\$s は %1\$s を削除しました",
"You shared %1\$s with %2\$s" => "あなたは %1\$s を %2\$s と共有しました",
"You shared %1\$s with group %2\$s" => "あなたは %1\$s をグループ %2\$s と共有しました",
"%2\$s shared %1\$s with you" => "%2\$s は %1\$s をあなたと共有しました",
"You shared %1\$s via link" => "リンク経由で %1\$s を共有しています",
"Activity notification" => "アクティビティ通知",
"All Activities" => "すべてのアクティビティ",
"Activities by you" => "あなたのアクティビティ",
"Activities by others" => "他人のアクティビティ",
"Shares" => "共有",
"Files" => "ファイル",
"%s and %s" => "%s と %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s と <strong class=\"tooltip\" title=\"%s\">それ以外に %n 個</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s と それ以外に %n 個"),
"Hello %s," => "%s さんこんにちは、",
"You are receiving this email because in the last hour the following things happened at %s" => "このメールは、最近１時間に %s で以下の事象が発生したことをお知らせするものです。",
"You are receiving this email because in the last day the following things happened at %s" => "このメールは、最近１日間に %s で以下の事象が発生したことをお知らせするものです。",
"You are receiving this email because in the last week the following things happened at %s" => "このメールは、最近１週間に %s で以下の事象が発生したことをお知らせするものです。",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "%s の使用を開始すると、ここでイベントリストを見ることができます。",
"No more events to load" => "これ以上読み込むイベントはありません",
"Enable RSS feed" => "RSSフィードを有効にする",
"Notifications" => "通知",
"Mail" => "メール",
"Stream" => "ストリーム",
"Notify about my own actions" => "自身のアクションを通知する",
"You need to set up your email address before you can receive notification emails." => "通知メールを受け取る前にメールアドレスを設定する必要があります。",
"Send emails:" => "メールを送信:",
"Hourly" => "1時間毎",
"Daily" => "毎日",
"Weekly" => "毎週",
"Activity feed" => "アクティビティフィード",
"Personal activity feed for %s" => "\"%s\" の個人アクティビティフィード"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
